@@ -656,11 +656,15 @@ hildon_bread_crumb_trail_push_text (HildonBreadCrumbTrail *bct,
   g_return_if_fail (text != NULL);
 
   widget = _hildon_bread_crumb_widget_new_with_text (text);
+  if (bct->priv->item_list == NULL)
+    {
+      g_object_set (G_OBJECT (widget), "show-separator", FALSE, NULL);
+    }
   attach_bread_crumb (bct, widget, id, destroy);
 }
 
 /**
- * hildon_bread_crumb_trail_push_text:
+ * hildon_bread_crumb_trail_push_icon:
  * @bct: pointer to #HildonBreadCrumbTrail
  * @text: content of the new bread crumb
  * @icon: a widget to set as the icon in the bread crumb
@@ -687,6 +691,10 @@ hildon_bread_crumb_trail_push_icon (HildonBreadCrumbTrail *bct,
   g_return_if_fail (GTK_IS_WIDGET (icon));
 
   widget = _hildon_bread_crumb_widget_new_with_icon (icon, text);
+  if (bct->priv->item_list == NULL)
+    {
+      g_object_set (G_OBJECT (widget), "show-separator", FALSE, NULL);
+    }
   attach_bread_crumb (bct, widget, id, destroy);
 }
 
